@@ -18,7 +18,8 @@ public:
     bool isValid ();
 
 public slots:
-    void initiateCall (const QString &strDestination);
+    void initiateCall (const QString &strDestination, void *ctx = NULL);
+    bool sendDTMF(const QString &strTones);
 
 private slots:
     void onSkypeConnected (bool bSuccess, const QVariantList &params);
